@@ -15,7 +15,7 @@ from .core import (
     render_components_md,
     use_inline_tables,
 )
-from .settings import EmailSettings, SlackSettings, logger
+from .settings import AlertMsgs, EmailSettings, SlackSettings, logger
 
 
 def send_email(
@@ -23,6 +23,7 @@ def send_email(
     components: List[AlertComponent],
     settings: Optional[EmailSettings] = None,
     n_attempts: int = 2,
+    **_,
 ) -> bool:
     """Send an email using SMTP.
 
@@ -107,6 +108,7 @@ def send_slack_message(
     components: List[AlertComponent],
     settings: Optional[SlackSettings] = None,
     n_attempts: int = 2,
+    **_,
 ):
     # TODO attachments.
     settings = settings or SlackSettings()
@@ -117,7 +119,7 @@ def send_slack_message(
     )
     for _ in range(n_attempts):
         resp = requests.post(settings.webhook, json={"text": body, "mrkdwn": True})
-        logger.info(f"[{resp.status_code}] {settings.webhook}")
+        logger.debug(f"[{resp.status_code}] {settings.webhook}")
         if resp.status_code == 200:
             logger.info("Slack alert sent successfully.")
             return True
@@ -127,11 +129,24 @@ def send_slack_message(
 
 
 def send_alert(
-    method: Union["email", "slack"], components: List[AlertComponent], **kwargs
+    components: List[AlertComponent],
+    methods: Optional[Union["email", "slack"]] = None,
+    **kwargs,
 ):
-    methods = {"email": send_email, "slack": send_slack_message}
-    if not (func := methods.get(method)):
-        raise ValueError(
-            f"Unknown method '{method}'. Valid choices {', '.join(methods.keys())}"
-        )
-    return func(components=components, **kwargs)
+    if isinstance(methods, str):
+        methods = [methods]
+    elif methods is None:
+        methods = []
+        settings = AlertMsgs()
+        if settings.alert_slack:
+            methods.append("slack")
+        if settings.send_email:
+            methods.append("email")
+    funcs = []
+    if "email" in methods:
+        funcs.append(send_email)
+    if "slack" in methods:
+        funcs.append(send_slack_message)
+    if not funcs:
+        raise ValueError(f"Unknown method '{methods}'. Valid choices: slack, email.")
+    return all([func(components=components, **kwargs) for func in funcs])
