@@ -20,12 +20,8 @@ def use_inline_tables(tables: List[Table], inline_tables_max_rows: int) -> bool:
     Returns:
         bool: Whether inline tables can be used.
     """
-    if (row_count := sum([len(t.rows) for t in tables])) < inline_tables_max_rows:
-        logger.info(
-            f"Inline tables can be used. Total table row count ({row_count}) is less than max allowed ({inline_tables_max_rows})"
-        )
+    if sum([len(t.rows) for t in tables]) < inline_tables_max_rows:
         return True
-    logger.info("Can not use inline tables because tables have too many rows.")
     return False
 
 
@@ -41,10 +37,10 @@ def attach_tables(tables: List[Table], attachments_max_size_mb: int) -> bool:
     """
     tables_size_mb = sum([sys.getsizeof(t.rows) for t in tables]) / 10 ** 6
     if tables_size_mb < attachments_max_size_mb:
-        logger.info(f"Adding {len(tables)} tables as attachments.")
+        logger.debug(f"Adding {len(tables)} tables as attachments.")
         return True
     else:
-        logger.info(
+        logger.debug(
             f"Can not add tables as attachments because size {tables_size_mb}mb exceeds max {attachments_max_size_mb}"
         )
         return False
