@@ -14,7 +14,7 @@ class EmailSettings(BaseSettings):
     smtp_port: int = 465
 
     class Config:
-        env_prefix = "alerts_email_"
+        env_prefix = "alert_msgs_email_"
 
 
 class SlackSettings(BaseSettings):
@@ -23,4 +23,12 @@ class SlackSettings(BaseSettings):
     inline_tables_max_rows: int = 200
 
     class Config:
-        env_prefix = "alerts_slack_"
+        env_prefix = "alert_msgs_slack_"
+
+
+class AlertMsgs(BaseSettings):
+    send_email: bool
+    alert_slack: bool
+
+    class Config:
+        env_prefix = "alert_msgs_"
